django-payu [![BuildStatus](https://travis-ci.org/PressLabs/django-payu.svg?branch=payu-token)](https://travis-ci.org/PressLabs/django-payu)
===========

Django integration for PayU (ex. ePayment). This is not a reference implementation.
Only a subset of featues is implemented (partially IPN and LiveUpdate).


LICENSE
===========

Copyright 2012-2016 PressLabs SRL

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
